@@ -4,7 +4,7 @@
 import logging
 from isbntools.dev.webquery import query as wquery
 from isbntools.dev import stdmeta
-from isbntools.bouth23 import u
+from isbntools.dev.bouth23 import u
 from isbntools.dev.exceptions import (NoDataForSelectorError,
                                       RecordMappingError)
 
