@@ -73,3 +73,9 @@ class NoAPIKeyError(ISBNToolsDevException):
     """ Exception raised when the API Key for a service is not found
     """
     message = "this service needs an API key"
+
+
+class FileNotFoundError(ISBNToolsDevException):
+    """ Exception raised when a given file doesn't exist
+    """
+    message = "the file wasn't found"
